@@ -580,17 +580,16 @@ set_rrule_from_comp (ECalComponent *comp,
 		/* set exceptions */
 		if (e_cal_component_has_exdates (comp)) {
 			GSList *l, *item_exdate_list = NULL;
-			icaltimezone *default_zone, *utc;
+			icaltimezone *utc;
 			struct icaltimetype itt_utc;
 
 			e_cal_component_get_exdate_list (comp, &exdate_list);
 			utc = icaltimezone_get_utc_timezone ();
-			default_zone = utc;
 			for (l = exdate_list; l; l = l->next) {
 				ECalComponentDateTime *dt = (ECalComponentDateTime *) l->data;
 				if (dt->value) {
 					if (!icaltime_get_timezone (*(dt->value)))
-						icaltime_set_timezone (dt->value, icaltimezone_get_builtin_timezone_from_tzid(dt->tzid));
+						icaltime_set_timezone (dt->value, icaltimezone_get_builtin_timezone_from_tzid (dt->tzid));
 					itt_utc = icaltime_convert_to_zone (*dt->value, utc);
 					item_exdate_list = g_slist_append (item_exdate_list, icaltime_as_ical_string_r (itt_utc));
 				}
@@ -661,7 +660,7 @@ set_properties_from_cal_component (EGwItem *item,
 		e_cal_component_get_dtend (comp, &dt);
 		if (dt.value) {
 			if (!icaltime_get_timezone (*dt.value))
-				icaltime_set_timezone (dt.value, icaltimezone_get_builtin_timezone_from_tzid(dt.tzid));
+				icaltime_set_timezone (dt.value, icaltimezone_get_builtin_timezone_from_tzid (dt.tzid));
 			itt_utc = icaltime_convert_to_zone (*dt.value, utc);
 			value = icaltime_as_ical_string_r (itt_utc);
 			e_gw_item_set_end_date (item, value);
@@ -678,7 +677,7 @@ set_properties_from_cal_component (EGwItem *item,
 		e_cal_component_get_due (comp, &dt);
 		if (dt.value) {
 			if (!icaltime_get_timezone (*dt.value))
-				icaltime_set_timezone (dt.value, icaltimezone_get_builtin_timezone_from_tzid(dt.tzid));
+				icaltime_set_timezone (dt.value, icaltimezone_get_builtin_timezone_from_tzid (dt.tzid));
 			itt_utc = icaltime_convert_to_zone (*dt.value, utc);
 			value = icaltime_as_ical_string_r (itt_utc);
 			e_gw_item_set_due_date (item,  value);
@@ -754,7 +753,7 @@ set_properties_from_cal_component (EGwItem *item,
 	e_cal_component_get_dtstart (comp, &dt);
 	if (dt.value) {
 		if (!icaltime_get_timezone (*dt.value))
-			icaltime_set_timezone (dt.value, icaltimezone_get_builtin_timezone_from_tzid(dt.tzid));
+			icaltime_set_timezone (dt.value, icaltimezone_get_builtin_timezone_from_tzid (dt.tzid));
 		itt_utc = icaltime_convert_to_zone (*dt.value, utc);
 		value = icaltime_as_ical_string_r (itt_utc);
 		e_gw_item_set_start_date (item, value);
@@ -777,7 +776,7 @@ set_properties_from_cal_component (EGwItem *item,
 	e_cal_component_get_created (comp, &dt.value);
 	if (dt.value) {
 		if (!icaltime_get_timezone (*dt.value))
-			icaltime_set_timezone (dt.value, icaltimezone_get_builtin_timezone_from_tzid(dt.tzid));
+			icaltime_set_timezone (dt.value, icaltimezone_get_builtin_timezone_from_tzid (dt.tzid));
 		itt_utc = icaltime_convert_to_zone (*dt.value, utc);
 		value = icaltime_as_ical_string_r (itt_utc);
 		e_gw_item_set_creation_date (item, value);
