@@ -31,7 +31,7 @@
 #include <camel/camel.h>
 #include <e-gw-connection.h>
 #include <libedataserverui/e-passwords.h>
-#include "e-util/e-alert-dialog.h"
+#include <libevolution-utils/e-alert-dialog.h>
 #include <libecal/e-cal-client.h>
 #include <shell/e-shell.h>
 #include <libemail-utils/e-account-utils.h>
@@ -237,7 +237,7 @@ add_esource (const gchar *conf_key,
 	if (!can_create)
 		e_source_group_set_property (group, "create_source", "no");
 
-	port_string = g_strdup(soap_port);
+	port_string = g_strdup (soap_port);
 
 	relative_uri = g_strdup_printf ("%s@%s/", url->user, poa_address);
 	source = e_source_new (source_name, relative_uri);
@@ -435,7 +435,7 @@ modify_esource (const gchar *conf_key,
 			g_return_if_reached ();
 	}
 
-	port_string = g_strdup(soap_port);
+	port_string = g_strdup (soap_port);
 
 	for (; groups != NULL &&  !found_group; groups = g_slist_next (groups)) {
 		ESourceGroup *group = E_SOURCE_GROUP (groups->data);
@@ -722,7 +722,7 @@ add_addressbook_sources (EAccount *account)
 	if (!temp_list)
 		return FALSE;
 
-	port_string = g_strdup(soap_port);
+	port_string = g_strdup (soap_port);
 
 	for (; temp_list != NULL; temp_list = g_list_next (temp_list)) {
 		const gchar *book_name =  e_gw_container_get_name (E_GW_CONTAINER (temp_list->data));
@@ -850,7 +850,7 @@ modify_addressbook_sources (EAccount *account,
 			g_return_if_reached ();
 	}
 
-	port_string = g_strdup(soap_port);
+	port_string = g_strdup (soap_port);
 
 	new_base_uri = g_strdup_printf ("groupwise://%s@%s", url->user, poa_address);
 
@@ -1076,7 +1076,7 @@ account_changed (EAccountList *account_listener,
 		g_object_unref (settings);
 
 		if ((old_poa_address && strcmp (old_poa_address, new_poa_address))
-		   || strcmp(old_soap_port, new_soap_port)
+		   || strcmp (old_soap_port, new_soap_port)
 		   || strcmp (old_url->user, new_url->user)
 		   || old_security_method != new_security_method) {
 
