@@ -27,7 +27,7 @@
 #include <gconf/gconf-client.h>
 #include "shell/es-event.h"
 #include <string.h>
-#include <e-util/e-account-utils.h>
+#include <libemail-utils/e-account-utils.h>
 
 #define GROUPWISE_BASE_URI "groupwise://"
 
